### Name: domain.set
### Title: Define the Reference Domain
### Aliases: domain.set
### Keywords: classes

### ** Examples

# This example fills a grid with non-conditional simulations
# with a Model which varies per domain

# Create the grid
grid = db.create(nx=c(100,100))

# Simulate 3 domains using PGS
ncol = 3
rule = rule.create(c("S","S","F1","F2","F3"))
model.pgs = model.create(vartype="Cubic",range=30)
grid = simpgs(,grid,rule=rule,model1=model.pgs)

# Define each color as a Domain
grid = db.locate(grid,"SimPGS*","dom")

# Loop on the Domains
types = c("Nugget Effect","Gaussian","Exponential")
for (idom in 1:ncol)
{
  domain.set(domain=idom)
  model = model.create(vartype=types[idom],range=30)
  grid  = simtub(,grid,model,nbtuba=1000)
}
grid = db.merge(grid,names="Simu.*")
plot(grid,title="Merged Domains")



